<?php

namespace Bixo\Opportunity\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Bixo\Opportunity\Http\Requests\OffersRequest;
use Bixo\Opportunity\Interfaces\OffersRepositoryInterface;
use Bixo\Opportunity\Models\Offers;
use Bixo\Opportunity\Forms\Offers as Form;

/**
 * APIController  class for offers.
 */
class OffersAPIController extends BaseController
{

    /**
     * Initialize offers resource controller.
     *
     * @param type OffersRepositoryInterface $offers
     *
     * @return null
     */
    public function __construct(OffersRepositoryInterface $offers)
    {
        parent::__construct();
        $this->repository = $offers;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Bixo\Opportunity\Repositories\Criteria\OffersResourceCriteria::class);
    }

    /**
     * Display a list of offers.
     *
     * @return Response
     */
    public function index(OffersRequest $request)
    {
        return $this->repository
            ->setPresenter(\Bixo\Opportunity\Repositories\Presenter\OffersPresenter::class)
            ->paginate();
    }

    /**
     * Display offers.
     *
     * @param Request $request
     * @param Model   $offers
     *
     * @return Response
     */
    public function show(OffersRequest $request, Offers $offers)
    {
        return $offers->setPresenter(\Bixo\Opportunity\Repositories\Presenter\OffersListPresenter::class);
        ;
    }

    /**
     * Create new offers.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(OffersRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('opportunity::offers.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('opportunity/offers/' . $offers->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('opportunity/offers');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the offers.
     *
     * @param Request $request
     * @param Model   $offers
     *
     * @return Response
     */
    public function update(OffersRequest $request, Offers $offers)
    {
        try {
            $data = $request->all();

            $offers->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('opportunity::offers.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('opportunity/offers/' . $offers->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('opportunity/offers/' . $offers->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the offers.
     *
     * @param Model   $offers
     *
     * @return Response
     */
    public function destroy(OffersRequest $request, Offers $offers)
    {
        try {
            $offers->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('opportunity::offers.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('opportunity/offers/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('opportunity/offers/' . $offers->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
