<?php

namespace Bixo\Opportunity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Opportunity\Models\Offers;

class OffersPolicy
{

    /**
     * Determine if the given user can view the offers.
     *
     * @param UserPolicy $user
     * @param Offers $offers
     *
     * @return bool
     */
    public function view(UserPolicy $user, Offers $offers)
    {
        if ($user->canDo('opportunity.offers.view') && $user->isAdmin()) {
            return true;
        }

        return $offers->user_id == user_id() && $offers->user_type == user_type();
    }

    /**
     * Determine if the given user can create a offers.
     *
     * @param UserPolicy $user
     * @param Offers $offers
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('opportunity.offers.create');
    }

    /**
     * Determine if the given user can update the given offers.
     *
     * @param UserPolicy $user
     * @param Offers $offers
     *
     * @return bool
     */
    public function update(UserPolicy $user, Offers $offers)
    {
        if ($user->canDo('opportunity.offers.edit') && $user->isAdmin()) {
            return true;
        }

        return $offers->user_id == user_id() && $offers->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given offers.
     *
     * @param UserPolicy $user
     * @param Offers $offers
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Offers $offers)
    {
        return $offers->user_id == user_id() && $offers->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given offers.
     *
     * @param UserPolicy $user
     * @param Offers $offers
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Offers $offers)
    {
        if ($user->canDo('opportunity.offers.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given offers.
     *
     * @param UserPolicy $user
     * @param Offers $offers
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Offers $offers)
    {
        if ($user->canDo('opportunity.offers.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
