<?php

namespace Bixo\Opportunity\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bixo\Opportunity\Models\Opportunities;

class OpportunitiesPolicy
{

    /**
     * Determine if the given user can view the opportunities.
     *
     * @param UserPolicy $user
     * @param Opportunities $opportunities
     *
     * @return bool
     */
    public function view(UserPolicy $user, Opportunities $opportunities)
    {
        if ($user->canDo('opportunity.opportunities.view') && $user->isAdmin()) {
            return true;
        }

        return $opportunities->user_id == user_id() && $opportunities->user_type == user_type();
    }

    /**
     * Determine if the given user can create a opportunities.
     *
     * @param UserPolicy $user
     * @param Opportunities $opportunities
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('opportunity.opportunities.create');
    }

    /**
     * Determine if the given user can update the given opportunities.
     *
     * @param UserPolicy $user
     * @param Opportunities $opportunities
     *
     * @return bool
     */
    public function update(UserPolicy $user, Opportunities $opportunities)
    {
        if ($user->canDo('opportunity.opportunities.edit') && $user->isAdmin()) {
            return true;
        }

        return $opportunities->user_id == user_id() && $opportunities->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given opportunities.
     *
     * @param UserPolicy $user
     * @param Opportunities $opportunities
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Opportunities $opportunities)
    {
        return $opportunities->user_id == user_id() && $opportunities->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given opportunities.
     *
     * @param UserPolicy $user
     * @param Opportunities $opportunities
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Opportunities $opportunities)
    {
        if ($user->canDo('opportunity.opportunities.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given opportunities.
     *
     * @param UserPolicy $user
     * @param Opportunities $opportunities
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Opportunities $opportunities)
    {
        if ($user->canDo('opportunity.opportunities.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
