<?php

namespace Bixo\Opportunity\Providers;

use Illuminate\Support\ServiceProvider;

class OpportunityServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'opportunity');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'opportunity');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerOpportunity();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerOpportunity()
    {
        $this->app->bind('opportunity', function($app) {
            return new Opportunity($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Opportunity', 'Lavalite\Opportunity\Facades\Opportunity');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bixo.opportunity', function ($app) {
            return $this->app->make('Bixo\Opportunity\Opportunity');
        });

        // Bind Opportunities to repository
        $this->app->bind(
            'Bixo\Opportunity\Interfaces\OpportunitiesRepositoryInterface',
            \Bixo\Opportunity\Repositories\Eloquent\OpportunitiesRepository::class
        );        // Bind Offers to repository
        $this->app->bind(
            'Bixo\Opportunity\Interfaces\OffersRepositoryInterface',
            \Bixo\Opportunity\Repositories\Eloquent\OffersRepository::class
        );

        $this->app->register(\Bixo\Opportunity\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bixo\Opportunity\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and opportunity's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.opportunity'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeOpportunity::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.opportunity'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bixo/opportunity.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/opportunity')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/opportunity')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
